@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Bookmarks" : "Favoritter",
     "Failed to import one bookmark, because: " : "Kunne ikke importere et bogmærke, fordi:",
-    "Bookm." : "Bogm.",
     "No file provided for import" : "Ingen fil til import",
     "Unsupported file type for import" : "Denne filtype er ikke understøttet til import",
     "Add a Bookmark" : "Tilføj et bogmærke",
@@ -13,17 +12,11 @@ OC.L10N.register(
     "Delete" : "Slet",
     "Saved" : "Gemt",
     "No bookmarks here." : "Ingen bogmærker her.",
-    "All bookmarks" : "Alle bogmærker",
-    "Shared" : "Delt",
     "Settings" : "Indstillinger",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName} " : "Tilføj til {instanceName} ",
-    "Add to filter" : "Tilføj til filter",
-    "Remove from filter" : "Fjern fra filter",
-    "Rename" : "Omdøb",
     "An error occurred while trying to save the bookmark." : "Der opstod en fejl, da bogmærket skulle gemmes.",
     "Error" : "Fejl",
-    "Uploading..." : "Uploader...",
     "Import error" : "Importfejl",
     "Import completed successfully." : "Import afsluttet korrekt.",
     "Set tags" : "Sæt markering",
