@@ -3,10 +3,10 @@ OC.L10N.register(
     {
     "Bookmarks" : "Lesezeichen",
     "Failed to import one bookmark, because: " : "Ein Lesezeichen konnte nicht importiert werden, weil:",
-    "Bookm." : "Lesez.",
     "No file provided for import" : "Keine Datei zum Importieren ausgewählt",
     "Unsupported file type for import" : "Ein Import von Dateien dieses Typs wird nicht unterstützt",
     "Add a Bookmark" : "Lesezeichen hinzufügen",
+    "Add folder" : "Ordner hinzufügen",
     "Select" : "Auswählen",
     "Deselect" : "Abwählen",
     "Details" : "Details",
@@ -15,9 +15,7 @@ OC.L10N.register(
     "Tags" : "Schlagworte",
     "Description" : "Beschreibung",
     "No bookmarks here." : "Keine Lesezeichen vorhanden.",
-    "All bookmarks" : "Alle Lesezeichen",
-    "Untagged" : "Unmarkiert",
-    "Shared" : "Geteilt",
+    "Favorites" : "Favoriten",
     "Settings" : "Einstellungen",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName} " : "Hinzufügen zu {instanceName} ",
@@ -26,13 +24,10 @@ OC.L10N.register(
     "RSS Feed" : "RSS-Feed",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Alle Lesezeichen Deines Kontos dauerhaft löschen. Es gibt kein zurück!",
     "Delete all bookmarks" : "Alle Lesezeichen löschen",
-    "Add to filter" : "Zum Filter hinzufügen",
-    "Remove from filter" : "Vom Filter entfernen",
-    "Rename" : "Umbenennen",
     "Open details" : "Details öffnen",
     "An error occurred while trying to save the bookmark." : "Beim Speichern des Lesezeichens ist ein Fehler aufgetreten.",
     "Error" : "Fehler",
-    "Uploading..." : "Lade hoch…",
+    "Uncategorized" : "Ohne Kategorie",
     "Import error" : "Fehler beim Import",
     "Import completed successfully." : "Import erfolgreich beendet.",
     "Set tags" : "Schlagworte setzen",
