@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Bookmarks" : "Bookmarks",
     "Failed to import one bookmark, because: " : "Failed to import one bookmark, because: ",
-    "Bookm." : "Bookm.",
     "No file provided for import" : "No file provided for import",
     "Unsupported file type for import" : "Unsupported file type for import",
     "Add a Bookmark" : "Add a Bookmark",
@@ -13,17 +12,11 @@ OC.L10N.register(
     "Delete" : "Delete",
     "Saved" : "Saved",
     "No bookmarks here." : "No bookmarks here.",
-    "All bookmarks" : "All bookmarks",
-    "Shared" : "Shared",
     "Settings" : "Settings",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName} " : "Add to {instanceName} ",
-    "Add to filter" : "Add to filter",
-    "Remove from filter" : "Remove from filter",
-    "Rename" : "Rename",
     "An error occurred while trying to save the bookmark." : "An error occurred while trying to save the bookmark.",
     "Error" : "Error",
-    "Uploading..." : "Uploading...",
     "Import error" : "Import error",
     "Import completed successfully." : "Import completed successfully.",
     "Set tags" : "Set tags",
