@@ -3,12 +3,10 @@ OC.L10N.register(
     {
     "Bookmarks" : "Marcadores",
     "Failed to import one bookmark, because: " : "Fallo al importar un marcador, porque:",
-    "Bookm." : "Marcador",
     "No file provided for import" : "No se proporcionó ningún archivo para importar",
     "Unsupported file type for import" : "Tipo de archivo no admitido para importar",
     "Bookmarklet" : "Marcadores",
     "Error" : "Error",
-    "Uploading..." : "Subiendo...",
     "Import error" : "Error al importar",
     "Import completed successfully." : "Importar completado con éxito",
     "Add a bookmark" : "Agregar un marcador",
