@@ -14,18 +14,15 @@ OC.L10N.register(
     "Tags" : "Tunnisteet",
     "Description" : "Kuvaus",
     "No bookmarks here." : "Täällä ei ole kirjanmerkkejä.",
-    "All bookmarks" : "Kaikki kirjanmerkit",
-    "Shared" : "Jaettu",
     "Settings" : "Asetukset",
     "Recently added" : "Äskettäin lisätty",
     "Most visited" : "Vierailuimmat",
     "RSS Feed" : "RSS-syöte",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Poista kaikki tililläsi olevat kirjanmerkit pysyvästi. Tätä toimintoa ei voi perua!",
     "Delete all bookmarks" : "Poista kaikki kirjanmerkit",
-    "Rename" : "Nimeä uudelleen",
+    "Open details" : "Avaa yksityiskohdat",
     "An error occurred while trying to save the bookmark." : "Kirjanmerkin tallennusta yrittäessä tapahtui virhe.",
     "Error" : "Virhe",
-    "Uploading..." : "Lähetetään...",
     "Import error" : "Tuontivirhe",
     "Import completed successfully." : "Tuonti suoritettiin onnistuneesti.",
     "Set tags" : "Aseta tunnisteet",
