@@ -3,10 +3,10 @@ OC.L10N.register(
     {
     "Bookmarks" : "Segnalibri",
     "Failed to import one bookmark, because: " : "Importazione di un segnalibro non riuscita, motivo:",
-    "Bookm." : "Segnal.",
     "No file provided for import" : "Nessun file fornito per l'importazione",
     "Unsupported file type for import" : "Tipo di file non supportato per l'importazione",
     "Add a Bookmark" : "Aggiungi un segnalibro",
+    "Add folder" : "Aggiungi cartella",
     "Select" : "Seleziona",
     "Deselect" : "Deseleziona",
     "Details" : "Dettagli",
@@ -15,9 +15,7 @@ OC.L10N.register(
     "Tags" : "Etichette",
     "Description" : "Descrizione",
     "No bookmarks here." : "Qui non c'è alcun segnalibro",
-    "All bookmarks" : "Tutti i segnalibri",
-    "Untagged" : "Non etichettati",
-    "Shared" : "Condiviso",
+    "Favorites" : "Preferiti",
     "Settings" : "Impostazioni",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName} " : "Aggiungi a {instanceName} ",
@@ -26,13 +24,10 @@ OC.L10N.register(
     "RSS Feed" : "Fonte RSS",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Rimuovi definitivamente tutti i segnalibri dal tuo account. Non si torna indietro!",
     "Delete all bookmarks" : "Elimina tutti i segnalibri",
-    "Add to filter" : "Aggiungi a filtro",
-    "Remove from filter" : "Rimuovi da filtro",
-    "Rename" : "Rinomina",
     "Open details" : "Apri i dettagli",
     "An error occurred while trying to save the bookmark." : "Si è  verificato un errore durante il tentativo di salvataggio del segnalibro.",
     "Error" : "Errore",
-    "Uploading..." : "Caricamento in corso...",
+    "Uncategorized" : "Senza categoria",
     "Import error" : "Errore di importazione",
     "Import completed successfully." : "Importazione completata correttamente.",
     "Set tags" : "Imposta etichette",
