@@ -3,12 +3,10 @@ OC.L10N.register(
     {
     "Bookmarks" : "სანიშნეები",
     "Failed to import one bookmark, because: " : "ერთი სანიშნის იმპორტი ვერ მოხერხდა, რადგან:",
-    "Bookm." : "სანიშნ.",
     "No file provided for import" : "იმპორტისთვის ფაილი არაა მოწოდებული",
     "Unsupported file type for import" : "იმპორტისთვის მხარდაუჭერელი ფაილის სახეობა",
     "Bookmarklet" : "Bookmarklet-ი",
     "Error" : "შეცდომა",
-    "Uploading..." : "მიმდინარეობს ატვირთვა...",
     "Import error" : "იმპორტის შეცდომა",
     "Import completed successfully." : "იმპორტი წარმატებით დასრულდა.",
     "Add a bookmark" : "სანიშნის დამატება",
