@@ -7,9 +7,9 @@ OC.L10N.register(
     "Description" : "Aprašymas",
     "Settings" : "Nustatymai",
     "Bookmarklet" : "Išsaugojimo mygtukas",
+    "Add to {instanceName} " : "Pridėti į {instanceName} ",
     "RSS Feed" : "RSS kanalas",
     "Error" : "Klaida",
-    "Uploading..." : "Įkeliama...",
     "Import error" : "Įkėlimo klaida",
     "Import completed successfully." : "Įkelta",
     "The title of the page" : "Pavadinimas",
