@@ -3,10 +3,10 @@ OC.L10N.register(
     {
     "Bookmarks" : "Bladwijzers",
     "Failed to import one bookmark, because: " : "Mislukt om een bladwijzer te importeren, want:",
-    "Bookm." : "Bladw.",
     "No file provided for import" : "Geen bestand verschaft om te importeren",
     "Unsupported file type for import" : "Niet ondersteund bestandstype om te importeren",
     "Add a Bookmark" : "Toevoegen bladwijzer",
+    "Add folder" : "Toevoegen map",
     "Select" : "Selecteren",
     "Deselect" : "Deselecteren",
     "Details" : "Details",
@@ -15,9 +15,7 @@ OC.L10N.register(
     "Tags" : "Tags",
     "Description" : "Beschrijving",
     "No bookmarks here." : "Hier zijn geen bladwijzers.",
-    "All bookmarks" : "Alle bladwijzers",
-    "Untagged" : "Niet getagd",
-    "Shared" : "Gedeeld",
+    "Favorites" : "Favorieten",
     "Settings" : "Instellingen",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName} " : "Toevoegen aan {instanceName} ",
@@ -26,13 +24,10 @@ OC.L10N.register(
     "RSS Feed" : "RSS Feed",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Verwijder alle bladwijzers permanent uit je account. Je kunt niet terug!",
     "Delete all bookmarks" : "Verwijder alle bladwijzers",
-    "Add to filter" : "Toevoegen aan filter",
-    "Remove from filter" : "Verwijderen uit filter",
-    "Rename" : "Hernoemen",
     "Open details" : "Openen details",
     "An error occurred while trying to save the bookmark." : "Er trad een fout op bij je poging de bladwijzer op te slaan",
     "Error" : "Fout",
-    "Uploading..." : "Uploaden...",
+    "Uncategorized" : "Niet gecategoriseerd",
     "Import error" : "Importeer fout",
     "Import completed successfully." : "Importeren succesvol afgerond.",
     "Set tags" : "Instellen tags",
