@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Bookmarks" : "Zakładki",
     "Failed to import one bookmark, because: " : "Nie można było zaimportować jednej zakładki ponieważ:",
-    "Bookm." : "Bookm.",
     "No file provided for import" : "Brak pliku do importu",
     "Unsupported file type for import" : "NIewspierany typ pliku importowania",
     "Add a Bookmark" : "Dodaj Zakładkę",
@@ -15,9 +14,6 @@ OC.L10N.register(
     "Tags" : "Tagi",
     "Description" : "Opis",
     "No bookmarks here." : "Brak tutaj zakładek.",
-    "All bookmarks" : "Wszystkie zakładki",
-    "Untagged" : "Bez tagów",
-    "Shared" : "Udostępnione",
     "Settings" : "Ustawienia",
     "Bookmarklet" : "Skryptozakładka",
     "Add to {instanceName} " : "Dodaj do {instanceName} ",
@@ -26,13 +22,9 @@ OC.L10N.register(
     "RSS Feed" : "Kanał RSS",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Trwale usuń wszystkie zakładki ze swojego konta. Operacja nieodwracalna!",
     "Delete all bookmarks" : "Usuń wszystkie zakładki",
-    "Add to filter" : "Dodaj do filtra",
-    "Remove from filter" : "Usuń z filtra",
-    "Rename" : "Zmień nazwę",
     "Open details" : "Otwórz szczegóły",
     "An error occurred while trying to save the bookmark." : "Wystąpił błąd podczas próby zapisania zakładki.",
     "Error" : "Błąd",
-    "Uploading..." : "Wysyłanie…",
     "Import error" : "Błąd importu",
     "Import completed successfully." : "Importowanie zakończone pomyślnie.",
     "Set tags" : "Ustaw tagi",
