@@ -3,10 +3,10 @@ OC.L10N.register(
     {
     "Bookmarks" : "Favoritos",
     "Failed to import one bookmark, because: " : "Falha ao importar os favoritos, porque: ",
-    "Bookm." : "Fav.",
     "No file provided for import" : "Nenhum arquivo para importar",
     "Unsupported file type for import" : "O tipo de arquivo não é suportado",
     "Add a Bookmark" : "Adicionar um marcador",
+    "Add folder" : "Adicionar pasta",
     "Select" : "Selecionar",
     "Deselect" : "Desselecionar",
     "Details" : "Detalhes",
@@ -15,9 +15,7 @@ OC.L10N.register(
     "Tags" : "Etiquetas",
     "Description" : "Descrição",
     "No bookmarks here." : "Não há marcadores aqui.",
-    "All bookmarks" : "Todos os favoritos",
-    "Untagged" : "Sem marcação",
-    "Shared" : "Compartilhado",
+    "Favorites" : "Favoritos",
     "Settings" : "Configurações",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName} " : "Adicionar a {instanceName} ",
@@ -26,13 +24,10 @@ OC.L10N.register(
     "RSS Feed" : "Feed RSS",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Remover permanentemente todos os favoritos. Não há como desfazer isso!",
     "Delete all bookmarks" : "Excluir todos os favoritos",
-    "Add to filter" : "Adicionar ao filtro",
-    "Remove from filter" : "Excluir do filtro",
-    "Rename" : "Renomear",
     "Open details" : "Abrir detalhes",
     "An error occurred while trying to save the bookmark." : "Um erro ocorreu enquanto tentava salvar o favorito.",
     "Error" : "Erro",
-    "Uploading..." : "Enviando...",
+    "Uncategorized" : "Não categorizado",
     "Import error" : "Erro na importação",
     "Import completed successfully." : "Importação finalizada com sucesso.",
     "Set tags" : "Atribuir tags",
