@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Bookmarks" : "Zaznamki",
     "Failed to import one bookmark, because: " : "Uvoz izbranega zaznamka je spodletel:",
-    "Bookm." : "Zaznamek",
     "No file provided for import" : "Ni navedenih datotek za uvoz",
     "Unsupported file type for import" : "Nepodprta vrsta datoteke za uvoz",
     "Add a Bookmark" : "Dodaj zaznamek",
@@ -15,9 +14,6 @@ OC.L10N.register(
     "Tags" : "Oznake",
     "Description" : "Opis",
     "No bookmarks here." : "Ni še dodanih zaznamkov.",
-    "All bookmarks" : "Vsi zaznamki",
-    "Untagged" : "Neoznačeno",
-    "Shared" : "V souporabi",
     "Settings" : "Nastavitve",
     "Add to {instanceName} " : "Dodaj {instanceName} ",
     "Recently added" : "Nedavno dodano",
@@ -25,13 +21,9 @@ OC.L10N.register(
     "RSS Feed" : "Vir RSS",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Trajno odstrani vse zaznamke, povezane z računom. Dejanja ni mogoče povrniti!",
     "Delete all bookmarks" : "Izbriši vse zaznamke",
-    "Add to filter" : "Dodaj v filter",
-    "Remove from filter" : "Odstrani iz filtra",
-    "Rename" : "Preimenuj",
     "Open details" : "Odpri podrobnosti",
     "An error occurred while trying to save the bookmark." : "Prišlo je do napake med shranjevanjem zaznamka.",
     "Error" : "Napaka",
-    "Uploading..." : "Poteka pošiljanje ...",
     "Import error" : "Napaka uvoza",
     "Import completed successfully." : "Uvoz je uspešno končan.",
     "Set tags" : "Nastavitve oznak",
