@@ -7,17 +7,12 @@ OC.L10N.register(
     "Saved" : "U ruajt",
     "Tags" : "Etiketat",
     "Description" : "Përshkrimi",
-    "Untagged" : "E paetiketuar",
-    "Shared" : "Ndarë",
     "Settings" : "Konfigurime",
     "Add to {instanceName} " : "Shto në {instanceName}",
     "Recently added" : "Shtuar së fundmi",
     "Most visited" : "Vizituar më shpesh",
-    "Remove from filter" : "Hiqe nga filtrat",
-    "Rename" : "Riemërto",
     "Open details" : "Hapni detajet",
     "Error" : "Gabim",
-    "Uploading..." : "Duke ngarkuar...",
     "Import completed successfully." : "Importimi përfundoi me sukses.",
     "Set tags" : "Përcaktoni etiketat",
     "The title of the page" : "Titulli i faqes",
