@@ -3,10 +3,10 @@ OC.L10N.register(
     {
     "Bookmarks" : "Забелешке",
     "Failed to import one bookmark, because: " : "Грешка приликом увоза забелешке, зато што:",
-    "Bookm." : "Забелеш.",
     "No file provided for import" : "Није дат фајл за увоз",
     "Unsupported file type for import" : "Неподржани тип фајла за увоз",
     "Add a Bookmark" : "Додај забелешку",
+    "Add folder" : "Додај фасциклу",
     "Select" : "Изабери",
     "Deselect" : "Поништи избор",
     "Details" : "Детаљи",
@@ -15,9 +15,7 @@ OC.L10N.register(
     "Tags" : "Ознаке",
     "Description" : "Опис",
     "No bookmarks here." : "Овде нема забелешки",
-    "All bookmarks" : "Све забелешке",
-    "Untagged" : "Неозначене",
-    "Shared" : "Дељене",
+    "Favorites" : "Омиљени",
     "Settings" : "Поставке",
     "Bookmarklet" : "Забележник",
     "Add to {instanceName} " : "Додај на {instanceName} ",
@@ -26,13 +24,10 @@ OC.L10N.register(
     "RSS Feed" : "RSS довод",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Трајно брише све забелешке са налога. Нема назад!",
     "Delete all bookmarks" : "Обриши све забелешке",
-    "Add to filter" : "Додај у филтер",
-    "Remove from filter" : "Уклони из филтера",
-    "Rename" : "Преименуј",
     "Open details" : "Отвори детаље",
     "An error occurred while trying to save the bookmark." : "Дошло је до грешке при покушају чувања забелешке.",
     "Error" : "Грешка",
-    "Uploading..." : "Отпремам…",
+    "Uncategorized" : "Некатегоризовано",
     "Import error" : "Грешка приликом увоза",
     "Import completed successfully." : "Увоз успешно завршен.",
     "Set tags" : "Постави ознаке",
