@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Bookmarks" : "Bokmärken",
     "Failed to import one bookmark, because: " : "Misslyckades att importera bokmärken eftersom:",
-    "Bookm." : "Bokm.",
     "No file provided for import" : "Inga filer given för importering",
     "Unsupported file type for import" : "Ogiltig filtyp för import",
     "Add a Bookmark" : "Lägg till ett bokmärke",
@@ -15,9 +14,6 @@ OC.L10N.register(
     "Tags" : "Taggar",
     "Description" : "Beskrivning",
     "No bookmarks here." : "Inga bokmärken här.",
-    "All bookmarks" : "Alla bokmärken",
-    "Untagged" : "Inte taggad",
-    "Shared" : "Delad",
     "Settings" : "Inställningar",
     "Add to {instanceName} " : "Lägg till {instanceName} ",
     "Recently added" : "Nyligen tillagd",
@@ -25,13 +21,9 @@ OC.L10N.register(
     "RSS Feed" : "RSS-flöde",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Ta bort alla bokmärken permanent från ditt konto. Det går inte att ångra!",
     "Delete all bookmarks" : "Ta bort alla bokmärken",
-    "Add to filter" : "Lägg till filter",
-    "Remove from filter" : "Ta bort filter",
-    "Rename" : "Byt namn",
     "Open details" : "Öppna detaljer",
     "An error occurred while trying to save the bookmark." : "Ett fel uppstod när bokmärket skulle sparas.",
     "Error" : "Fel",
-    "Uploading..." : "Laddar upp...",
     "Import error" : "Importeringsfel",
     "Import completed successfully." : "Importen slutfördes utan problem.",
     "Set tags" : "Ange taggar",
