@@ -3,10 +3,10 @@ OC.L10N.register(
     {
     "Bookmarks" : "Yer İmleri",
     "Failed to import one bookmark, because: " : "Bir yer imi şu nedenle içe aktarılamadı:",
-    "Bookm." : "Yer imi",
     "No file provided for import" : "İçe aktarılacak bir dosya seçilmemiş",
     "Unsupported file type for import" : "İçe aktarılacak dosya türü desteklenmiyor",
     "Add a Bookmark" : "Yer İmi Ekle",
+    "Add folder" : "Klasör ekle",
     "Select" : "Seç",
     "Deselect" : "Bırak",
     "Details" : "Ayrıntılar",
@@ -15,9 +15,7 @@ OC.L10N.register(
     "Tags" : "İşaretler",
     "Description" : "Açıklama",
     "No bookmarks here." : "Henüz bir yer imi yok.",
-    "All bookmarks" : "Tüm yer imleri",
-    "Untagged" : "İşaretlenmemiş",
-    "Shared" : "Paylaşılan",
+    "Favorites" : "Sık Kullanılanlar",
     "Settings" : "Ayarlar",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName} " : "{instanceName} üzerine ekle  ",
@@ -26,13 +24,10 @@ OC.L10N.register(
     "RSS Feed" : "RSS Akışı",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Hesabınızdaki tüm yer imlerini kalıcı olarak siler. Bu işlem geri alınamaz!",
     "Delete all bookmarks" : "Tüm yer imlerini sil",
-    "Add to filter" : "Süzgece ekle",
-    "Remove from filter" : "Süzgeçten kaldır",
-    "Rename" : "Yeniden adlandır",
     "Open details" : "Ayrıntıları aç",
     "An error occurred while trying to save the bookmark." : "Yer imi kaydedilmeye çalışılırken bir sorun çıktı.",
     "Error" : "Hata",
-    "Uploading..." : "Yükleniyor...",
+    "Uncategorized" : "Kategorisiz",
     "Import error" : "İçe aktarma sorunu",
     "Import completed successfully." : "İçe aktarma tamamlandı.",
     "Set tags" : "Etiketleri ayarla",
