@@ -3,10 +3,10 @@ OC.L10N.register(
     {
     "Bookmarks" : "书签",
     "Failed to import one bookmark, because: " : "无法导入一个书签，因为：",
-    "Bookm." : "书签.",
     "No file provided for import" : "未提供导入文件",
     "Unsupported file type for import" : "不支持导入的文件类型",
     "Add a Bookmark" : "添加书签",
+    "Add folder" : "添加文件夹",
     "Select" : "选择",
     "Deselect" : "取消选择",
     "Details" : "详情",
@@ -15,9 +15,7 @@ OC.L10N.register(
     "Tags" : "标签",
     "Description" : "描述",
     "No bookmarks here." : "没有书签.",
-    "All bookmarks" : "全部书签",
-    "Untagged" : "未标记的",
-    "Shared" : "已分享的",
+    "Favorites" : "收藏",
     "Settings" : "设置",
     "Bookmarklet" : "小书签",
     "Add to {instanceName} " : "添加到 {instanceName}",
@@ -26,13 +24,10 @@ OC.L10N.register(
     "RSS Feed" : "RSS ",
     "Permanently remove all bookmarks from your account. There is no going back!" : "永久删除您帐户中的所有书签. 此操作无法恢复!",
     "Delete all bookmarks" : "删除所有书签",
-    "Add to filter" : "添加到过滤器",
-    "Remove from filter" : "删除过滤器",
-    "Rename" : "重命名",
     "Open details" : "打开详情",
     "An error occurred while trying to save the bookmark." : "尝试保存书签时发生错误.",
     "Error" : "错误",
-    "Uploading..." : "正在上传...",
+    "Uncategorized" : "未分类",
     "Import error" : "导入错误",
     "Import completed successfully." : "导入完全成功.",
     "Set tags" : "设置标签",
